import { useCallback, useEffect, useState } from 'react';
import reactLogo from './assets/react.svg';
import { invoke } from '@tauri-apps/api/tauri';
import './App.css';
import clsx from 'clsx';
import { Configurator } from './configurator/configurator';

type Mode = 'Flowing' | 'Follow' | null;

function App() {
  const [screenshots, setScreenshots] = useState<string[]>([]);
  const [ledStripColors, setLedStripColors] = useState<string[]>([]);
  const [currentMode, setCurrentMode] = useState<Mode>(null);

  async function takeSnapshot() {
    const base64TextList: string[] = await invoke('take_snapshot');

    setScreenshots(base64TextList.map((text) => `data:image/webp;base64,${text}`));
  }

  const getLedStripColors = useCallback(async () => {
    setLedStripColors(await invoke('get_led_strip_colors'));
  }, []);

  const switchCurrentMode = useCallback(
    async (targetMode: Mode) => {
      console.log(targetMode, currentMode, currentMode === targetMode);
      if (currentMode === targetMode) {
        await invoke('play_mode', { targetMode: 'None' });
        setCurrentMode(null);
      } else {
        await invoke('play_mode', { targetMode });
        setCurrentMode(targetMode);
      }
      console.log(targetMode, currentMode, currentMode === targetMode);
    },
    [currentMode, setCurrentMode],
  );

  return (
    <div>
      <div className="flex justify-between">
        {ledStripColors.map((it) => (
          <span className=" h-8 flex-auto" style={{ backgroundColor: it }}></span>
        ))}
      </div>

      <div className="flex gap-1 justify-center w-screen overflow-hidden">
        {screenshots.map((screenshot) => (
          <div className="flex-auto">
            <img src={screenshot} />
          </div>
        ))}
      </div>

      <div className="flex gap-5 justify-center ">
        <button
          className="bg-black bg-opacity-20"
          type="button"
          onClick={() => readPickerConfig()}
        >
          Refresh Displays
        </button>
        <button
          className="bg-black bg-opacity-20"
          type="button"
          onClick={() => takeSnapshot()}
        >
          Take Snapshot
        </button>
        <button
          className="bg-black bg-opacity-20"
          type="button"
          onClick={() => getLedStripColors()}
        >
          Get Colors
        </button>
        <button
          className={clsx('bg-black', 'bg-opacity-20', {
            'bg-gradient-to-r from-purple-500 to-blue-500': currentMode === 'Flowing',
          })}
          type="button"
          onClick={() => switchCurrentMode('Flowing')}
        >
          Flowing Light
        </button>
        <button
          className={clsx('bg-black', 'bg-opacity-20', {
            'bg-gradient-to-r from-purple-500 to-blue-500': currentMode === 'Follow',
          })}
          type="button"
          onClick={() => switchCurrentMode('Follow')}
        >
          Follow
        </button>
      </div>

      <div className="flex gap-5 justify-center">
        <Configurator />
      </div>
    </div>
  );
}

export default App;
